/*///////////////////////////////////////////////////////////////////////////////*/
/**/
/* Inactive Protection Macro definition*/
/**/
/*///////////////////////////////////////////////////////////////////////////////*/
/**/
/* When Protection is inactive, the PTC_Function is define as Function*/
/**/
/*///////////////////////////////////////////////////////////////////////////////*/
 
 
#ifndef _PTCMACRO_H_	/* {*/
#define _PTCMACRO_H_
 
#ifndef PTC_SYSTEM_ACTIVED	/* {*/
 
/*///////////////////////////////////////////////////////////////////////////////*/
 
#define PTC_fn_vInit(x)
#define PTC_fn_vDesInit()
#define PTC_fn_bVerifyOneImportedFunctionPtr()		TRUE
#define PTC_fn_lGetRandom()							0L
#define PTC_fn_lGetRandomRange(a,b)					(a)
 
#define PTC_GetModuleHandle					GetModuleHandle
#define PTC_GetModuleHandleA				GetModuleHandleA
#define PTC_FlushInstructionCache			FlushInstructionCache
#define PTC_GetCurrentProcess				GetCurrentProcess
#define PTC_QueryPerformanceFrequency		QueryPerformanceFrequency
#define PTC_OpenEventA						OpenEventA
#define PTC_CreateEventA					CreateEventA
#define PTC_ResetEvent						ResetEvent
#define PTC_SetEvent						SetEvent
#define PTC_CreateFile						CreateFile
#define PTC_WriteFile						WriteFile
#define PTC_ReadFile						ReadFile
#define PTC_CloseHandle						CloseHandle
#define PTC_SetFilePointer					SetFilePointer
#define PTC_FlushFileBuffers				FlushFileBuffers
#define PTC_QueryPerformanceCounter			QueryPerformanceCounter
#define PTC_GetDriveType					GetDriveType
#define PTC_GetVolumeInformation			GetVolumeInformation
#define PTC_GetLogicalDriveStrings			GetLogicalDriveStrings
#define PTC_GetFileSize						GetFileSize
#define PTC_CreateToolhelp32Snapshot		CreateToolhelp32Snapshot
#define PTC_Process32First					Process32First
#define PTC_Process32Next					Process32Next
#define PTC_Module32First					Module32First
#define PTC_Module32Next					Module32Next
#define PTC_EnumProcesses					EnumProcesses
#define PTC_EnumProcessModules				EnumProcessModules
#define PTC_LoadLibrary						LoadLibrary
#define PTC_FreeLibrary						FreeLibrary
/* ANNECY OA - 21/07/99 { */
#define PTC_GetDiskFreeSpace				GetDiskFreeSpace
#define PTC_SetFileAttributs				SetFileAttributs
#define PTC_GetFileAttributs				GetFileAttributs
#define PTC_GetFileInformationByHandle		GetFileInformationByHandle
#define PTC_SetErrorMode					SetErrorMode
#define PTC_SetFileTime						SetFileTime
#define PTC_GetFileTime						GetFileTime
/* END ANNECY OA } */


 
/*///////////////////////////////////////////////////////////////////////////////*/

#define PTC_M_SetLabelAddress(lValue,label)         
#define PTC_M_BeginLabel(function)                  
#define PTC_M_EndLabel(function)                    
#define PTC_M_DeclareBeginLabel(function)           
#define PTC_M_DeclareEndLabel(function)             

#define PTC_M_AddFunctionCheckSum(index,function)
#define PTC_M_AddFunctionDelete(index,function)

#define PTC_fn_vInitChecksum()
#define PTC_fn_vComputeAndWriteChecksumFile()
#define PTC_fn_dwlGetCheckSum(dwBeginAddr,dwEndAddr)
#define PTC_fn_vReadChecksumFile()
#define PTC_fn_dwSearchExportedFunctionInEveryDLL(_szCryptedName)	0
#define PTC_fn_dwSearchFunctionInImportedTableOfExe(_szCryptedName)	0

/*///////////////////////////////////////////////////////////////////////////////*/

#define PTC_g_bTakeAddresses					0

#endif /* ! PTC_SYSTEM_ACTIVED	}*/
 
#endif /* ! _PTCMACRO_H_	}*/
 
/*///////////////////////////////////////////////////////////////////////////////*/
/* End Of File*/
/*///////////////////////////////////////////////////////////////////////////////*/
